#ifndef __json_strerror_override_private_h__
#define __json_strerror_override_private_h__

/**
 * @file
 * @brief Do not use, json-c internal, may be changed or removed at any time.
 */

#include "json_types.h"

/* Used by tests to get consistent output */
JSON_EXPORT int _json_c_strerror_enable;

#endif
